summaryrefslogtreecommitdiffstats
path: root/src/occ_405/amec/amec_health.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/occ_405/amec/amec_health.c')
-rwxr-xr-xsrc/occ_405/amec/amec_health.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/occ_405/amec/amec_health.c b/src/occ_405/amec/amec_health.c
index 4efad15..85c7a7d 100755
--- a/src/occ_405/amec/amec_health.c
+++ b/src/occ_405/amec/amec_health.c
@@ -760,9 +760,9 @@ void amec_health_check_proc_temp()
/*------------------------------------------------------------------------*/
do
{
// Get TEMP2MSP0PEAK sensor, which is hottest core temperature
// in OCC processor
- l_sensor = getSensorByGsid(TEMP2MSP0PEAK);
+ l_sensor = getSensorByGsid(TEMP4MSP0PEAK);
l_ot_error = g_amec->thermalproc.ot_error;
// Check to see if we exceeded our error temperature
@@ -874,7 +874,7 @@ void amec_health_check_proc_timeout()
}
// Check if this core's temperature sensor has been updated
- l_sensor = AMECSENSOR_ARRAY_PTR(TEMP2MSP0C0,i);
+ l_sensor = AMECSENSOR_ARRAY_PTR(TEMP4MSP0C0,i);
if (l_sensor->update_tag == G_core_temp_update_tag[i])
{
// If the update tag is not changing, then this core's
@@ -760,9 +760,9 @@ void amec_health_check_proc_temp()
do
{
- // Get TEMP2MSP0PEAK sensor, which is hottest core temperature
+ // Get TEMP4MSP0PEAK sensor, which is hottest core temperature
// in OCC processor
OpenPOWER on IntegriCloud